==> mono-2.8.2.tar.bz2: mono-2.8.2/mono/mini/patch-info.h <==
PATCH_INFO(BB, "bb")
PATCH_INFO(ABS, "abs")
PATCH_INFO(LABEL, "label")
PATCH_INFO(METHOD, "method")
PATCH_INFO(METHOD_JUMP, "method_jump")
PATCH_INFO(METHOD_REL, "method_rel")
PATCH_INFO(METHODCONST, "methodconst")
PATCH_INFO(INTERNAL_METHOD, "internal_method")
PATCH_INFO(SWITCH, "switch")
PATCH_INFO(EXC, "exc")
PATCH_INFO(EXC_NAME, "exc_name")
PATCH_INFO(CLASS, "class")
PATCH_INFO(IMAGE, "image")
PATCH_INFO(FIELD, "field")
PATCH_INFO(VTABLE, "vtable")
PATCH_INFO(CLASS_INIT, "class_init")
PATCH_INFO(SFLDA, "sflda")
PATCH_INFO(LDSTR, "ldstr")
PATCH_INFO(LDTOKEN, "ldtoken")
PATCH_INFO(TYPE_FROM_HANDLE, "type_from_handle")
PATCH_INFO(R4, "r4")
PATCH_INFO(R8, "r8")
PATCH_INFO(IP, "ip")
PATCH_INFO(IID, "iid")
PATCH_INFO(ADJUSTED_IID, "adjusted_iid")
PATCH_INFO(BB_OVF, "bb_ovf")
PATCH_INFO(EXC_OVF, "exc_ovf")
PATCH_INFO(GOT_OFFSET, "got_offset")
PATCH_INFO(DECLSEC, "declsec")
PATCH_INFO(RVA, "rva")
PATCH_INFO(DELEGATE_TRAMPOLINE, "delegate_trampoline")
PATCH_INFO(ICALL_ADDR, "icall_addr")
PATCH_INFO(JIT_ICALL_ADDR, "jit_icall_addr")
PATCH_INFO(INTERRUPTION_REQUEST_FLAG, "interruption_request_flag")
PATCH_INFO(METHOD_RGCTX, "method_rgctx")
PATCH_INFO(RGCTX_FETCH, "rgctx_fetch")
PATCH_INFO(GENERIC_CLASS_INIT, "generic_class_init")
PATCH_INFO(MONITOR_ENTER, "monitor_enter")
PATCH_INFO(MONITOR_EXIT, "monitor_exit")
PATCH_INFO(MSCORLIB_GOT_ADDR, "mscorlib_got_addr")
PATCH_INFO(SEQ_POINT_INFO, "seq_point_info")
PATCH_INFO(LLVM_IMT_TRAMPOLINE, "llvm_imt_trampoline")
PATCH_INFO(GC_CARD_TABLE_ADDR, "gc_card_table_addr")
PATCH_INFO(NONE, "none")

==> mono-4.0.1.28.tar.bz2: mono-4.0.1/mono/mini/patch-info.h <==
PATCH_INFO(BB, "bb")
PATCH_INFO(ABS, "abs")
PATCH_INFO(LABEL, "label")
PATCH_INFO(METHOD, "method")
PATCH_INFO(METHOD_JUMP, "method_jump")
PATCH_INFO(METHOD_REL, "method_rel")
PATCH_INFO(METHODCONST, "methodconst")
/* Either the address of a C function implementing a JIT icall, or a wrapper around it */
PATCH_INFO(INTERNAL_METHOD, "internal_method")
PATCH_INFO(SWITCH, "switch")
PATCH_INFO(EXC, "exc")
PATCH_INFO(EXC_NAME, "exc_name")
PATCH_INFO(CLASS, "class")
PATCH_INFO(IMAGE, "image")
PATCH_INFO(FIELD, "field")
PATCH_INFO(VTABLE, "vtable")
PATCH_INFO(CLASS_INIT, "class_init")
PATCH_INFO(SFLDA, "sflda")
PATCH_INFO(LDSTR, "ldstr")
PATCH_INFO(LDTOKEN, "ldtoken")
PATCH_INFO(TYPE_FROM_HANDLE, "type_from_handle")
PATCH_INFO(R4, "r4")
PATCH_INFO(R8, "r8")
PATCH_INFO(IP, "ip")
PATCH_INFO(IID, "iid")
PATCH_INFO(ADJUSTED_IID, "adjusted_iid")
PATCH_INFO(BB_OVF, "bb_ovf")
PATCH_INFO(EXC_OVF, "exc_ovf")
PATCH_INFO(GOT_OFFSET, "got_offset")
PATCH_INFO(DECLSEC, "declsec")
PATCH_INFO(RVA, "rva")
PATCH_INFO(DELEGATE_TRAMPOLINE, "delegate_trampoline")
PATCH_INFO(ICALL_ADDR, "icall_addr")
/* The address of a C function implementing a JIT icall */
PATCH_INFO(JIT_ICALL_ADDR, "jit_icall_addr")
PATCH_INFO(INTERRUPTION_REQUEST_FLAG, "interruption_request_flag")
PATCH_INFO(METHOD_RGCTX, "method_rgctx")
PATCH_INFO(RGCTX_FETCH, "rgctx_fetch")
PATCH_INFO(GENERIC_CLASS_INIT, "generic_class_init")
PATCH_INFO(MONITOR_ENTER, "monitor_enter")
PATCH_INFO(MONITOR_ENTER_V4, "monitor_enter_v4")
PATCH_INFO(MONITOR_EXIT, "monitor_exit")
PATCH_INFO(MSCORLIB_GOT_ADDR, "mscorlib_got_addr")
PATCH_INFO(SEQ_POINT_INFO, "seq_point_info")
PATCH_INFO(LLVM_IMT_TRAMPOLINE, "llvm_imt_trampoline")
PATCH_INFO(GC_CARD_TABLE_ADDR, "gc_card_table_addr")
PATCH_INFO(CASTCLASS_CACHE, "castclass_cache")
PATCH_INFO(SIGNATURE, "signature")
PATCH_INFO(GSHAREDVT_CALL, "gsharedvt_call")
PATCH_INFO(GSHAREDVT_METHOD, "gsharedvt_method")
PATCH_INFO(JIT_TLS_ID, "jit_tls_id")
PATCH_INFO(TLS_OFFSET, "tls_offset")
PATCH_INFO(OBJC_SELECTOR_REF, "objc_selector_ref")
PATCH_INFO(METHOD_CODE_SLOT, "method_code_slot")
PATCH_INFO(LDSTR_LIT, "ldstr_lit")
PATCH_INFO(NONE, "none")
